import React from 'react';
import { Box, Typography } from '@mui/material';
import styled from 'styled-components';
import LocalGasStationIcon from '@mui/icons-material/LocalGasStation'; // Icon for refilling indicator.

export interface SlotData {
    id: string;
    qr_code: string;
    label: string;
    qr_base: string;
    occupied: boolean;
    dewar_unique_id?: string; // Optional additional information.
    dewar_name?: string;     // Optional dewar information.
    needs_refill?: boolean;  // Indicator for refill requirement.
}

interface SlotProps {
    data: SlotData;
    isSelected: boolean;
    onSelect: (slot: SlotData) => void;
}

const StyledSlot = styled(Box)<{ isSelected: boolean; isOccupied: boolean }>`
    padding: 16px;
    margin: 8px;
    width: 150px;           // Increase the width to accommodate more info.
    height: 150px;          // Increase the height to accommodate more info.
    background-color: ${({ isSelected, isOccupied }) =>
            isSelected ? '#3f51b5' : isOccupied ? '#f44336' : '#4caf50'};
    color: white;
    cursor: pointer;
    display: flex;
    flex-direction: column;
    justify-content: space-between;
    align-items: center;
    border-radius: 8px;
    box-shadow: 2px 2px 10px rgba(0, 0, 0, 0.1);
    transition: transform 0.2s;

    &:hover {
        transform: scale(1.05);
    }
`;

const Slot: React.FC<SlotProps> = ({ data, isSelected, onSelect }) => {
    return (
        <StyledSlot
            isSelected={isSelected}
            isOccupied={data.occupied}
            onClick={() => onSelect(data)}
        >
            <Typography variant="h6">{data.label}</Typography>
            {data.dewar_name && (
                <Typography variant="body2">{`Dewar: ${data.dewar_name}`}</Typography>
            )}
            {data.dewar_unique_id && (
                <Typography variant="body2">{`ID: ${data.dewar_unique_id}`}</Typography>
            )}
            {data.needs_refill && <LocalGasStationIcon />}
        </StyledSlot>
    );
};

export default Slot;