import React, { useState } from 'react';
import { Box, Typography } from '@mui/material';
import styled from 'styled-components';
import Slot, { SlotData } from '../components/Slots';

const StorageContainer = styled(Box)`
    display: flex;
    flex-direction: column;
    align-items: center;
    margin-top: 20px;
    width: 100%;
`;

const StorageWrapper = styled.div`
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    width: 90%;
    background-color: #dcdcdc;
    padding: 20px;
    border-radius: 10px;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    margin-bottom: 20px;
`;

interface StorageProps {
    name: string;
    selectedSlot: string | null;
    slotsData: SlotData[];
    onSelectSlot: (slot: SlotData) => void;
}

const Storage: React.FC<StorageProps> = ({ name, selectedSlot, slotsData, onSelectSlot }) => {
    const [highlightedSlot, setHighlightedSlot] = useState<SlotData | null>(null);

    const handleSlotSelect = (slot: SlotData) => {
        setHighlightedSlot(slot);
        onSelectSlot(slot);
        console.log('Selected slot:', slot);
    };

    console.log("Rendering Storage Component with name:", name);

    return (
        <StorageContainer>
            <Typography variant="h5">{name} Slots</Typography>
            <StorageWrapper>
                {slotsData.map((slot: SlotData) => (
                    <Slot
                        key={slot.id}
                        data={slot}
                        onSelect={handleSlotSelect}
                        isSelected={selectedSlot === slot.qr_code}
                    />
                ))}
            </StorageWrapper>
            {highlightedSlot && (
                <Typography variant="subtitle1">
                    Selected Slot: {highlightedSlot.label}
                </Typography>
            )}
        </StorageContainer>
    );
};

export default Storage;